package com.ruoyi.app.service;

import com.ruoyi.app.domain.AppVehicle;
import com.ruoyi.app.domain.DTO.AppAvailVehicle;

import java.util.List;

/**
 * 【请填写功能名称】Service接口
 *
 * @author ruoyi
 * @date 2025-01-15
 */
public interface IAppVehicleService
{
    /**
     * 查询【请填写功能名称】
     *
     * @param vehicleId 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public AppVehicle selectAppVehicleByVehicleId(String vehicleId);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param appVehicle 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<AppVehicle> selectAppVehicleList(AppVehicle appVehicle);

    /**
     * 新增【请填写功能名称】
     *
     * @param appVehicle 【请填写功能名称】
     * @return 结果
     */
    public int insertAppVehicle(AppVehicle appVehicle);

    /**
     * 修改【请填写功能名称】
     *
     * @param appVehicle 【请填写功能名称】
     * @return 结果
     */
    public int updateAppVehicle(AppVehicle appVehicle);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param vehicleIds 需要删除的【请填写功能名称】主键集合
     * @return 结果
     */
    public int deleteAppVehicleByVehicleIds(String[] vehicleIds);

    /**
     * 删除【请填写功能名称】信息
     *
     * @param vehicleId 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteAppVehicleByVehicleId(String vehicleId);

    /**
     * 获取状态为在库中的所有可用的载具
     */
    public List<AppAvailVehicle> selectAppAvailVehicleList();
}
