package com.ruoyi.web.controller.app;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.app.domain.AppVehicle;
import com.ruoyi.app.domain.DTO.AppAvailVehicle;
import com.ruoyi.app.service.IAppVehicleService;
import com.ruoyi.common.annotation.Anonymous;
import com.ruoyi.web.controller.section.EnhanceDataList;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 【请填写功能名称】Controller
 *
 * @author ruoyi
 * @date 2025-01-15
 */
@RestController
@RequestMapping("/app/vehicle")
public class AppVehicleController extends BaseController
{
    @Autowired
    private IAppVehicleService appVehicleService;

    /**
     * 查询【请填写功能名称】列表
     */
    @PreAuthorize("@ss.hasPermi('system:vehicle:list')")
    @GetMapping("/list")
    @EnhanceDataList(entityType = AppVehicle.class)
    public TableDataInfo list(AppVehicle appVehicle)
    {
        startPage();
        List<AppVehicle> list = appVehicleService.selectAppVehicleList(appVehicle);
        return getDataTable(list);
    }

    /**
     * 导出【请填写功能名称】列表
     */
    @PreAuthorize("@ss.hasPermi('system:vehicle:export')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AppVehicle appVehicle)
    {
        List<AppVehicle> list = appVehicleService.selectAppVehicleList(appVehicle);
        ExcelUtil<AppVehicle> util = new ExcelUtil<AppVehicle>(AppVehicle.class);
        util.exportExcel(response, list, "【请填写功能名称】数据");
    }

    /**
     * 获取【请填写功能名称】详细信息
     */
    @GetMapping(value = "/{vehicleId}")
    @Anonymous
    public AjaxResult getInfo(@PathVariable("vehicleId") String vehicleId)
    {
        return success(appVehicleService.selectAppVehicleByVehicleId(vehicleId));
    }

    /**
     * 新增【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:vehicle:add')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AppVehicle appVehicle)
    {
        return toAjax(appVehicleService.insertAppVehicle(appVehicle));
    }

    /**
     * 修改【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:vehicle:edit')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppVehicle appVehicle)
    {
        return toAjax(appVehicleService.updateAppVehicle(appVehicle));
    }

    /**
     * 删除【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:vehicle:remove')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.DELETE)
    @DeleteMapping("/{vehicleIds}")
    public AjaxResult remove(@PathVariable String[] vehicleIds)
    {
        return toAjax(appVehicleService.deleteAppVehicleByVehicleIds(vehicleIds));
    }

    @GetMapping("listAvail")
    @Anonymous
    public List<AppAvailVehicle> selectAppAvailVehicleList() {
        return appVehicleService.selectAppAvailVehicleList();
    }
}
